==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/GetApplicationAcceleratorPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationAcceleratorName The name of the application accelerator.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class GetApplicationAcceleratorPlainArgs(
    public val applicationAcceleratorName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs.builder()
            .applicationAcceleratorName(applicationAcceleratorName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetApplicationAcceleratorPlainArgs].
 */
@PulumiTagMarker
public class GetApplicationAcceleratorPlainArgsBuilder internal constructor() {
    private var applicationAcceleratorName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the application accelerator.
     */
    @JvmName("ogqilaxqgyxjpciv")
    public suspend fun applicationAcceleratorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationAcceleratorName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("rqwgwxjhfkxmnanp")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("budrxhkwlfkrdkbq")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetApplicationAcceleratorPlainArgs = GetApplicationAcceleratorPlainArgs(
        applicationAcceleratorName = applicationAcceleratorName ?: throw
            PulumiNullFieldException("applicationAcceleratorName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/GetApplicationAcceleratorPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationAcceleratorName The name of the application accelerator.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class GetApplicationAcceleratorPlainArgs(
    public val applicationAcceleratorName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.GetApplicationAcceleratorPlainArgs.builder()
            .applicationAcceleratorName(applicationAcceleratorName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetApplicationAcceleratorPlainArgs].
 */
@PulumiTagMarker
public class GetApplicationAcceleratorPlainArgsBuilder internal constructor() {
    private var applicationAcceleratorName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the application accelerator.
     */
    @JvmName("cqdtlldxmwhghbgy")
    public suspend fun applicationAcceleratorName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationAcceleratorName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("jcdvsthcashlnakj")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("xddvbfiqsydxlybo")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetApplicationAcceleratorPlainArgs = GetApplicationAcceleratorPlainArgs(
        applicationAcceleratorName = applicationAcceleratorName ?: throw
            PulumiNullFieldException("applicationAcceleratorName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
    )
}
